#<profile4xi profile = "12" />
# -------------------------------------------------------------------------------------------------
#<program4xi program = "constant_pool4xi.py">
#<abstract4xi abstract = "Provides the class ConstantPool4Xi."/>
#<refer4xi reference = "pool.py"/>
#<state4xi status = "ACK4tagging; ACK4moduletesting; NACK4systemtesting; [Rel 7.21]"/>
# -------------------------------------------------------------------------------------------------
#

# -------------------------------------------------------------------------------------------------
# Public API
# -------------------------------------------------------------------------------------------------
#<interface4xi interface = " 
__all__ = [ 'constant_pool4xi', 'ConstantPool4Xi', 'init_all_pool4xi', 'get_all_pool4xi', 'set_all_pool4xi'
            'init_run_pool4xi', 'get_run_pool4xi', 'set_run_pool4xi',
            'init_close_pool4xi', 'get_close_pool4xi', 'set_close_pool4xi',
            'init_terminate_pool4xi', 'get_terminate_pool4xi', 'set_terminate_pool4xi',
            'init_exitpriority_pool4xi', 'get_exitpriority_pool4xi', 'set_exitpriority_pool4xi',
            'init_job_counter_pool4xi', 'get_job_counter_pool4xi', 'set_job_counter_pool4xi', 'next_job_counter_pool4xi']
#"
#/>

# -------------------------------------------------------------------------------------------------
# Standard Imports                          
# -------------------------------------------------------------------------------------------------
#<standardize4xi standard = "
try:                 # system ones
    import os
    import sys
    import signal
except:
    pass
try:                 # threading ones       
    import threading                
    import _thread   
except:
    pass
try:
    import _winapi
except:
    pass    
try:                 # most-common ones
    import errno
    import time
    import tempfile
    import itertools         
except:
    pass
try:                 # rare ones
    import socket         
except:
    pass 
#"
#/>

# -------------------------------------------------------------------------------------------------
# Multiprocessing Imports                          
# -------------------------------------------------------------------------------------------------
#<process4xi process = "
try:                             # Binary ones
    import _multiprocessing
except:
    pass
try:                             # Python ones
    from multiprocessing.pool import Pool
except:
    print("constant_pool4xi.py *** failed in from multiprocessing.pool import Pool ***")
#"
#/>
     
# -------------------------------------------------------------------------------------------------
# Global constants                            
# ------------------------------------------------------------------------------------------------
#<globalize4xi globalization = "
global RUN_POOL4XI
global CLOSE_POOL4XI
global TERMINATE_POOL4XI
global EXITPRIORITY_POOL4XI
#"
#/>

# -------------------------------------------------------------------------------------------------
# Definitions
# -------------------------------------------------------------------------------------------------
#<define4xi definition = "
RUN_POOL4XI = 0                                
CLOSE_POOL4XI = 1
TERMINATE_POOL4XI = 2
EXITPRIORITY_POOL4XI = 15
#"
#/>

# -------------------------------------------------------------------------------------------------
# Global object                              
# -------------------------------------------------------------------------------------------------
#<globalize4xi globalization = "
global job_counter4xi # dragonized job_counter
#"
#/>

# -------------------------------------------------------------------------------------------------
# Definitions
# -------------------------------------------------------------------------------------------------
#<define4xi definition = "
job_counter4xi = itertools.count()
#"
#/>

                      

# -------------------------------------------------------------------------------------------------
# DragonXi imports                              
# -------------------------------------------------------------------------------------------------
#<dragonize4xi dragonization = "
from ace_object4xi import ace_object4xi
from print4xi import print4xi
from reason_object4xi import reason_object4xi
from sense_object4xi import sense_object4xi
from time4xi import time4xi
#"
#/>

# -------------------------------------------------------------------------------------------------
#<function4xi function = "constant-pool4xi" usage = "
# defines constants for pools
#
# usage example:
#     pool4xi.py
#        apply(self, func, args=(), kwds={}):
#            assert self._state == get_run_pool4xi() #RUN_POOL4XI
#"> 
#<state4xi status = "<NACK4review; NACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
# -------------------------------------------------------------------------------------------------
def constant_pool4xi(constant_pool4xi_param):
    '''
    constant_pool4xi defines constants for pools

    '''
    global RUN_POOL4XI
    global CLOSE_POOL4XI
    global TERMINATE_POOL4XI
    global EXITPRIORITY_POOL4XI
    global job_counter4xi    
    
    class2print = 'constant_pool4xi'
    method2print = 'constant_pool4xi'
            
    message2print = "{started" + "; constant-pool4xi-started: " + str(constant_pool4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)     
    

    
    if constant_pool4xi_param == 1:

        message2print = "{returning" + "; RUN-POOL4XI-returning-by-constant-pool4xi: " + str(RUN_POOL4XI) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)   
        
        
        return RUN_POOL4XI

    if constant_pool4xi_param == 2:

        message2print = "{returning" + "; CLOSE-POOL4XI-returning-by-constant-pool4xi: " + str(CLOSE_POOL4XI) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)   
   
        return CLOSE_POOL4XI        

    if constant_pool4xi_param == 3:

        message2print = "{returning" + "; TERMINATE-POOL4XI-returning-by-constant-pool4xi: " + str(TERMINATE_POOL4XI) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)   
   
        return TERMINATE_POOL4XI
    
    if constant_pool4xi_param == 4:

        message2print = "{returning" + "; EXITPRIORITY-POOL4XI-returning-by-constant-pool4xi: " + str(EXITPRIORITY_POOL4XI) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)   
   
        return EXITPRIORITY_POOL4XI 
     
    if constant_pool4xi_param == 5:

        message2print = "{returning" + "; job-counter4xi-returning-by-constant-pool4xi: " + str(job_counter4xi) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)   
   
        return job_counter4xi 
                   
    message2print = "{returning" + "; False-returning-by-constant-pool4xi: " + str(False) + "; time: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)         
    
    return False        
#</function4xi> 

 
#1/5#
# -------------------------------------------------------------------------------------------------
#<function4xi function = "init-run-pool4xi" usage = "
# initializes RUN_POOL4XI
#"> 
#<state4xi status = "<NACK4review; NACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
# -------------------------------------------------------------------------------------------------    
def init_run_pool4xi(init_run_pool4xi_param=0):          
    '''
    init_run_pool4xi initializes RUN_POOL4XI
    '''
    global RUN_POOL4XI
    
    class2print = 'init_run_pool4xi'
    method2print = 'init_run_pool4xi'
            
    message2print = "{started" + "; init-run-pool4xi-started: " + str(init_run_pool4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)     
    

    RUN_POOL4XI = init_run_pool4xi_param
    
    message2print = "{initialized" + "; RUN-POOL4XI-initialized-by-init-run-pool4xi to: " + str(RUN_POOL4XI)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)         
    
    message2print = "{returning" + "; init-run-pool4xi-returning: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)      
                
#</function4xi> 

         

  

# -------------------------------------------------------------------------------------------------
#<function4xi function = "set-run-pool4xi" usage = "
# sets RUN_POOL4XI
#"> 
#<state4xi status = "<NACK4review; NACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
# -------------------------------------------------------------------------------------------------    
def set_run_pool4xi(set_run_pool4xi_param=0):          
    '''
    set_run_pool4xi sets RUN_POOL4XI
    '''
    global RUN_POOL4XI
    
    class2print = 'set_run_pool4xi'
    method2print = 'set_run_pool4xi'
            
    message2print = "{started" + "; set-run-pool4xi-started: " + str(set_run_pool4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)     
    

    RUN_POOL4XI = set_run_pool4xi_param

    message2print = "{set" + "; RUN-POOL4XI-set-by-set-run-pool4xi to: " + str(RUN_POOL4XI)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)  
            
    message2print = "{returning" + "; set-run-pool4xi-returning: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)      
              
#</function4xi> 

         

         
    
# -------------------------------------------------------------------------------------------------
#<function4xi function = "get-run-pool4xi" usage = "
# gets RUN_POOL4XI
#"> 
#<state4xi status = "<NACK4review; NACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
# -------------------------------------------------------------------------------------------------    
def get_run_pool4xi():          
    '''
    get_run_pool4xi gets RUN_POOL4XI
    '''
    global RUN_POOL4XI

        
    class2print = 'get_run_pool4xi'
    method2print = 'get_run_pool4xi'
            
    message2print = "{started" + "; get-run-pool4xi-started: " + str(get_run_pool4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print) 
        
    message2print = "{returning" + "; RUN-POOL4XI-returning-by-get-run-pool4xi: " + str(RUN_POOL4XI) + "; time: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)   
        
                
    return RUN_POOL4XI        
#</function4xi> 

 
#2/5#
# -------------------------------------------------------------------------------------------------
#<function4xi function = "init-close-pool4xi" usage = "
# initializes CLOSE_POOL4XI
#"> 
#<state4xi status = "<NACK4review; NACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
# -------------------------------------------------------------------------------------------------    
def init_close_pool4xi(init_close_pool4xi_param=1):          
    '''
    init_close_pool4xi initializes CLOSE_POOL4XI
    '''
    global CLOSE_POOL4XI
    
    class2print = 'init_close_pool4xi'
    method2print = 'init_close_pool4xi'
            
    message2print = "{started" + "; init-close-pool4xi-started: " + str(init_close_pool4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)     
    

    CLOSE_POOL4XI = init_close_pool4xi_param
    
    message2print = "{initialized" + "; CLOSE-POOL4XI-initialized-by-init-close-pool4xi to: " + str(CLOSE_POOL4XI)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)    
    
    message2print = "{returning" + "; init-close-pool4xi-returning: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)      
                     
#</function4xi> 

 
        

     

# -------------------------------------------------------------------------------------------------
#<function4xi function = "set-close-pool4xi" usage = "
# sets CLOSE_POOL4XI
#"> 
#<state4xi status = "<NACK4review; NACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
# -------------------------------------------------------------------------------------------------    
def set_close_pool4xi(set_close_pool4xi_param=1):          
    '''
    set_close_pool4xi sets CLOSE_POOL4XI
    '''
    global CLOSE_POOL4XI
    
    class2print = 'set_close_pool4xi'
    method2print = 'set_close_pool4xi'
            
    message2print = "{started" + "; set-close-pool4xi-started: " + str(set_close_pool4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)     
    

    CLOSE_POOL4XI = set_close_pool4xi_param
    
    message2print = "{set" + "; CLOSE-POOL4XI-set-by-set-close-pool4xi to: " + str(CLOSE_POOL4XI)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)  
              
    message2print = "{returning" + "; set-close-pool4xi-returning: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)      
        
#</function4xi> 

         

         
    
# -------------------------------------------------------------------------------------------------
#<function4xi function = "get-close-pool4xi" usage = "
# gets CLOSE_POOL4XI
#"> 
#<state4xi status = "<NACK4review; NACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
# -------------------------------------------------------------------------------------------------    
def get_close_pool4xi():          
    '''
    get_close_pool4xi gets CLOSE_POOL4XI
    '''
    global CLOSE_POOL4XI

        
    class2print = 'get_close_pool4xi'
    method2print = 'get_close_pool4xi'
            
    message2print = "{started" + "; get-close-pool4xi-started: " + str(get_close_pool4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print) 
        
    message2print = "{returning" + "; CLOSE_POOL4XI-returning-by-get-close-pool4xi: " + str(CLOSE_POOL4XI) + "; time: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)   
        
        
    return CLOSE_POOL4XI            
#</function4xi> 

 

#3/5#
# -------------------------------------------------------------------------------------------------
#<function4xi function = "init-terminate-pool4xi" usage = "
# initializes TERMINATE_POOL4XI
#"> 
#<state4xi status = "<NACK4review; NACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
# -------------------------------------------------------------------------------------------------    
def init_terminate_pool4xi(init_terminate_pool4xi_param=2):          
    '''
    init_terminate_pool4xi initializes TERMINATE_POOL4XI
    '''
    global TERMINATE_POOL4XI
    
    class2print = 'init_terminate_pool4xi'
    method2print = 'init_terminate_pool4xi'
            
    message2print = "{started" + "; init-terminate-pool4xi-started: " + str(init_terminate_pool4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)     
    

    TERMINATE_POOL4XI = init_terminate_pool4xi_param
    
    message2print = "{initialized" + "; TERMINATE-POOL4XI-initialized-by-init-terminate-pool4xi to: " + str(TERMINATE_POOL4XI)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)    
    
    message2print = "{returning" + "; init-terminate-pool4xi-returning: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)      
                      
#</function4xi> 

 
        

    

# -------------------------------------------------------------------------------------------------
#<function4xi function = "set-terminate-pool4xi" usage = "
# sets TERMINATE_POOL4XI
#"> 
#<state4xi status = "<NACK4review; NACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
# -------------------------------------------------------------------------------------------------    
def set_terminate_pool4xi(set_terminate_pool4xi_param=2):          
    '''
    set_terminate_pool4xi sets TERMINATE_POOL4XI
    '''
    global TERMINATE_POOL4XI
    
    class2print = 'set_terminate_pool4xi'
    method2print = 'set_terminate_pool4xi'
            
    message2print = "{started" + "; set-terminate-pool4xi-started: " + str(set_terminate_pool4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)     
    

    TERMINATE_POOL4XI = set_terminate_pool4xi_param
    
    message2print = "{set" + "; TERMINATE-POOL4XI-set-by-set-terminate-pool4xi to: " + str(TERMINATE_POOL4XI)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)  

    message2print = "{returning" + "; set-terminate-pool4xi-returning: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)      
            
                
#</function4xi> 

 
        

        
    
# -------------------------------------------------------------------------------------------------
#<function4xi function = "get-terminate-pool4xi" usage = "
# gets TERMINATE_POOL4XI
#"> 
#<state4xi status = "<NACK4review; NACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
# -------------------------------------------------------------------------------------------------    
def get_terminate_pool4xi():          
    '''
    get_terminate_pool4xi gets TERMINATE_POOL4XI
    '''
    global TERMINATE_POOL4XI

        
    class2print = 'get_terminate_pool4xi'
    method2print = 'get_terminate_pool4xi'
            
    message2print = "{started" + "; get-terminate-pool4xi-started: " + str(get_terminate_pool4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)     

    message2print = "{returning" + "; TERMINATE_POOL4XI-returning-by-get-terminate-pool4xi: " + str(TERMINATE_POOL4XI) + "; time: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)   
        
                  
    return TERMINATE_POOL4XI        

#</function4xi> 

     
#4/5#
# -------------------------------------------------------------------------------------------------
#<function4xi function = "init-exitpriority-pool4xi" usage = "
# initializes EXITPRIORITY_POOL4XI
#"> 
#<state4xi status = "<NACK4review; NACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
# -------------------------------------------------------------------------------------------------    
def init_exitpriority_pool4xi(init_exitpriority_pool4xi_param=15):          
    '''
    init_exitpriority_pool4xi initializes EXITPRIORITY_POOL4XI
    '''
    global EXITPRIORITY_POOL4XI
    
    class2print = 'init_exitpriority_pool4xi'
    method2print = 'init_exitpriority_pool4xi'
            
    message2print = "{started" + "; init-exitpriority-pool4xi-started: " + str(init_exitpriority_pool4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)     
    

    EXITPRIORITY_POOL4XI = init_exitpriority_pool4xi_param
    
    message2print = "{initialized" + "; EXITPRIORITY-POOL4XI-initialized-by-init-exitpriority-pool4xi to: " + str(EXITPRIORITY_POOL4XI)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)    
    
    message2print = "{returning" + "; init-exitpriority-pool4xi-returning: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)      
                      

#</function4xi> 

         

    

# -------------------------------------------------------------------------------------------------
#<function4xi function = "set-exitpriority-pool4xi" usage = "
# sets EXITPRIORITY_POOL4XI
#"> 
#<state4xi status = "<NACK4review; NACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
# -------------------------------------------------------------------------------------------------    
def set_exitpriority_pool4xi(set_exitpriority_pool4xi_param=15):          
    '''
    set_exitpriority_pool4xi sets EXITPRIORITY_POOL4XI
    '''
    global EXITPRIORITY_POOL4XI
    
    class2print = 'set_exitpriority_pool4xi'
    method2print = 'set_exitpriority_pool4xi'
            
    message2print = "{started" + "; set-exitpriority-pool4xi-started: " + str(set_exitpriority_pool4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)     
    

    EXITPRIORITY_POOL4XI = set_exitpriority_pool4xi_param
    
    message2print = "{set" + "; EXITPRIORITY-POOL4XI-set-by-set-exitpriority-pool4xi to: " + str(EXITPRIORITY_POOL4XI)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)  
              
    message2print = "{returning" + "; set-exitpriority-pool4xi-returning: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)      
        
#</function4xi> 

         

   
# -------------------------------------------------------------------------------------------------
#<function4xi function = "get-exitpriority-pool4xi" usage = "
# gets EXITPRIORITY_POOL4XI
#"> 
#<state4xi status = "<NACK4review; NACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
# -------------------------------------------------------------------------------------------------    
def get_exitpriority_pool4xi():          
    '''
    get_exitpriority_pool4xi gets EXITPRIORITY_POOL4XI
    '''
    global EXITPRIORITY_POOL4XI

        
    class2print = 'get_exitpriority_pool4xi'
    method2print = 'get_exitpriority_pool4xi'
            
    message2print = "{started" + "; get-exitpriority-pool4xi-started: " + str(get_exitpriority_pool4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)     
    
    message2print = "{returning" + "; EXITPRIORITY-POOL4XI-returning-by-get-exitpriority-pool4xi: " + str(EXITPRIORITY_POOL4XI) + "; time: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)   
        
                   
    return EXITPRIORITY_POOL4XI   
#</function4xi> 

 
#5/5#
# -------------------------------------------------------------------------------------------------
#<function4xi function = "init-job_counter-pool4xi" usage = "
# initializes job_counter4xi
#"> 
#<state4xi status = "<NACK4review; NACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
# -------------------------------------------------------------------------------------------------    
def init_job_counter_pool4xi(init_job_counter_pool4xi_param=itertools.count()):          
    '''
    init_job_counter_pool4xi initializes job_counter4xi
    '''
    global job_counter4xi
    
    class2print = 'init_job_counter_pool4xi'
    method2print = 'init_job_counter_pool4xi'
            
    message2print = "{started" + "; init-job_counter-pool4xi-started: " + str(init_job_counter_pool4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)     
    

    job_counter4xi = init_job_counter_pool4xi_param
    
    message2print = "{initialized" + "; job-counter4xi-initialized-by-init-job_counter-pool4xi to: " + str(job_counter4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)    
    
    message2print = "{returning" + "; init-job_counter-pool4xi-returning: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)      
                    
#</function4xi> 

         

    

# -------------------------------------------------------------------------------------------------
#<function4xi function = "set-job-counter-pool4xi" usage = "
# sets job_counter4xi
#"> 
#<state4xi status = "<NACK4review; NACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
# -------------------------------------------------------------------------------------------------    
def set_job_counter_pool4xi(set_job_counter_pool4xi_param=itertools.count()):          
    '''
    set_job_counter_pool4xi sets job_counter4xi
    '''
    global job_counter4xi
    
    class2print = 'set_job_counter_pool4xi'
    method2print = 'set_job_counter_pool4xi'
            
    message2print = "{started" + "; set-job-counter-pool4xi-started: " + str(set_job_counter_pool4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)     
    

    job_counter4xi = set_job_counter_pool4xi_param
    
    message2print = "{set" + "; job-counter4xi-set-by-set-job-counter-pool4xi to: " + str(job_counter4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)  
  
    message2print = "{returning" + "; set-job-counter-pool4xi-returning: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)      
                       

#</function4xi> 

         

        
    
# -------------------------------------------------------------------------------------------------
#<function4xi function = "get-job_counter-pool4xi" usage = "
# gets job_counter4xi
#"> 
#<state4xi status = "<NACK4review; NACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
# -------------------------------------------------------------------------------------------------    
def get_job_counter_pool4xi():          
    '''
    get_job_counter4xi gets job_counter4xi
    '''
    global job_counter4xi

        
    class2print = 'get_job_counter_pool4xi'
    method2print = 'get_job_counter_pool4xi'
            
    message2print = "{started" + "; get-job-counter-pool4xi-started: " + str(get_job_counter_pool4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)     

    message2print = "{returning" + "; job-counter4xi-returning-by-get-job_counter-pool4xi: " + str(job_counter4xi) + "; time: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)   
        
                  
    return job_counter4xi  
#</function4xi> 

     
# -------------------------------------------------------------------------------------------------
#<function4xi function = "next-job-counter-pool4xi" usage = "
# returns next job_counter4xi
#"> 
#<state4xi status = "<NACK4review; NACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
# -------------------------------------------------------------------------------------------------    
def next_job_counter_pool4xi():          
    '''
    next_job_counter4xi returns next job_counter4xi
    '''
    global job_counter4xi

        
    class2print = 'next_job_counter_pool4xi'
    method2print = 'next_job_counter_pool4xi'
    
    message2print = "{started" + "; next-job-counter-pool4xi-started: " + str(next_job_counter_pool4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print) 
        
    message2print = "{returning" + "; next-job-counter4xi-returning-by-next-job-counter-pool4xi: " + str(job_counter4xi) + "; time: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)   
        
    message2print = "{commented" + "; job-counter4xi-commented-by-next-job-counter-pool4xi: value is NOT increased for trace - values start from 0" + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)
         
          
    return next(job_counter4xi)                
#</function4xi> 

         
#All#
# -------------------------------------------------------------------------------------------------
#<function4xi function = "init-all-pool4xi" usage = "
# initializes all pool constants
#"> 
#<state4xi status = "<NACK4review; NACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
# -------------------------------------------------------------------------------------------------    
def init_all_pool4xi(init_all_pool4xi_param=1):          
    '''
    init_all_pool4xi initializes all pool constants
    '''

        
    class2print = 'init_all_pool4xi'
    method2print = 'init_all_pool4xi'
            
    message2print = "{started" + "; init-all-pool4xi-started: " + str(init_all_pool4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)     
    
 
    init_run_pool4xi()
    
    init_close_pool4xi()
    
    init_terminate_pool4xi()
    
    init_exitpriority_pool4xi()
    
    init_job_counter_pool4xi()
    
    message2print = "{returning" + "; init-all-pool4xi-returning: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)      
         
    
    
#</function4xi> 

         

# -------------------------------------------------------------------------------------------------
#<function4xi function = "set-all-pool4xi" usage = "
# sets all pool constants
#"> 
#<state4xi status = "<NACK4review; NACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
# -------------------------------------------------------------------------------------------------    
def set_all_pool4xi(set_all_pool4xi_param=1):          
    '''
    set_all_pool4xi sets all pool constants
    '''

        
    class2print = 'set_all_pool4xi'
    method2print = 'set_all_pool4xi'
            
    message2print = "{started" + "; set-all-pool4xi-started: " + str(set_all_pool4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print) 
        
          
        
    set_run_pool4xi()
    
    set_close_pool4xi()
    
    set_terminate_pool4xi()
    
    set_exitpriority_pool4xi()
    
    set_job_counter_pool4xi()
    
    message2print = "{returning" + "; set-all-pool4xi-returning: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)      
              
#</function4xi> 

     
# -------------------------------------------------------------------------------------------------
#<function4xi function = "get-all-pool4xi" usage = "
# gets all pool constants
#"> 
#<state4xi status = "<NACK4review; NACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
# -------------------------------------------------------------------------------------------------    
def get_all_pool4xi():          
    '''
    get_all_constant_pool4xi gets all pool constants
    '''
    # ---------------------------------------------------------------------------------------------
    # could return True after loading an OWL/XML file into memory 
    # ---------------------------------------------------------------------------------------------    

        
    class2print = 'get_all_pool4xi'
    method2print = 'get_all_pool4xi'
            
    message2print = "{started" + "; get-all-pool4xi-started: " + str(get_all_pool4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)     
     
    for i in range(1,6):
        print("constant_pool4xi(", i, ") = ", constant_pool4xi(i))

    message2print = "{returning" + "; True-returning-by-get-all-pool4xi: " + str(True) + "; time: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)   
        
            
    return True
#</function4xi> 

 
#ONE#    
# -------------------------------------------------------------------------------------------------
#<function4xi function = "get-one-constant_pool4xi" usage = "
# gets one pool constant
#"> 
#<state4xi status = "<NACK4review; NACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
# -------------------------------------------------------------------------------------------------    
def get_one_constant_pool4xi(get_one_constant_pool4xi_param=5):          
    '''
    get_one_constant_pool4xi gets one pool constant
    '''

        
    class2print = 'get_one_constant_pool4xi'
    method2print = 'get_one_constant_pool4xi'
            
    message2print = "{started" + "; get-one-constant-pool4xi-started: " + str(get_one_constant_pool4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)     
  
    if get_one_constant_pool4xi_param <= 0 or get_one_constant_pool4xi_param > 5:
        get_one_constant_pool4xi_param = 5    
 
    message2print = "{passing" + "; get-one-constant-pool4xi-param-passing-to-constant-pool4xi-by-get-one-constant-pool4xi: " + str(get_one_constant_pool4xi_param) + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)          
        
            
    message2print = "{returning" + "; constant-pool4xi-function-returning-by-get-one-constant-pool4xi: " + str(constant_pool4xi) + "; time: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print) 
        
    return constant_pool4xi(get_one_constant_pool4xi_param)    
#</function4xi> 

         
# =================================================================================================
#<class4xi class = "ConstantPool4Xi" base = "object" child = "None" synopsis = "offers services for pool constants" usage = "
#       SyncManager4Xi:__init__: cpool2xi = ConstantPool4Xi()"
#>
#<state4xi status = "<NACK4review; NACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
# =================================================================================================
class ConstantPool4Xi(object): #<-- inherits from object class
    '''
    ConstantPool4Xi offers services for pool constants
    ''' 
    # ---------------------------------------------------------------------------------------------
    # Public API of this class
    # ---------------------------------------------------------------------------------------------    
    #<expose4xi expose = "
    _exposed_ = ('init_all', 'get_all', 'set_all',
                 'init_run', 'get_run', 'set_run',
                 'init_close', 'get_close', 'set_close',
                 'init_terminate', 'get_terminate', 'set_terminate',
                 'init_exitpriority', 'get_exitpriority', 'set_exitpriority',
                 'init_job_counter', 'get_job_counter', 'set_job_counter', 'next_job_counterd',
                 'sense', 'reason', 'ace')          
    #"
    #/>
                                                
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "init-of-ConstantPool4Xi" usage = "initializes pool constants">
    #<state4xi status = "<NACK4review; NACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------   
    def __init__(self):
        '''
        _init__ method initializes pool constants
        '''       

            
        class2print = "ConstantPool4Xi"
        method2print = '__init__'
            
        message2print = "{started" + "; init-of-ConstantPool4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)        
        
        message2print = "{borning" + "; constantpool2xi-of-ConstantPool4Xi-borning: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)     

        message2print = "{inheriting" + "; object-inheriting-by-constantpool2xi-of-ConstantPool4Xi: " + str(object)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)         
        
                 
        init_all_pool4xi()        
        
        message2print = "{activated" + "; constantpool2xi-of-ConstantPool4Xi-activated: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)          

        message2print = "{inherited" + "; object-inherited-by-constantpool2xi-of-ConstantPool4Xi: " + str(object)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)         
         
        message2print = "{returning" + "; init-of-ConstantPool4Xi-returning: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print) 
                        
                
                              
    #</methodize4xi>
            
    
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "init-all-of-ConstantPool4Xi" usage = "initializes pool constants">
    #<state4xi status = "<NACK4review; NACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------   
    def init_all(self):
        '''
        init_all method initializes pool constants
        '''       

                    
        class2print = "ConstantPool4Xi"
        method2print = 'init_all'
            
        message2print = "{started" + "; init-all-of-ConstantPool4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)        
  
        init_all_pool4xi()   
    
        message2print = "{returning" + "; init-all-of-ConstantPool4Xi-returning: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)    
       
        
    #</methodize4xi>
    
             
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "set-all-of-ConstantPool4Xi" usage = "sets all pool constants">
    #<state4xi status = "<NACK4review; NACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------   
    def set_all(self):
        '''
        set_all method sets all pool constants
        '''       

                    
        class2print = "ConstantPool4Xi"
        method2print = 'set_all'
            
        message2print = "{started" + "; set-all-of-ConstantPool4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)        
  
        set_all_pool4xi()             
    
        message2print = "{returning" + "; set-all-of-ConstantPool4Xi-returning: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)  
    #</methodize4xi>
     
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "get-all-of-ConstantPool4Xi" usage = "gets all pool constants">
    #<state4xi status = "<NACK4review; NACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------   
    def get_all(self):
        '''
        get_all method gets all pool constants
        '''       

                    
        class2print = "ConstantPool4Xi"
        method2print = 'get_all'
            
        message2print = "{started" + "; get-all-of-ConstantPool4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)        
    
      
        message2print = "{returning" + "; get-all-pool4xi-function-returning-by-get-all-of-ConstantPool4Xi: " + str(get_all_pool4xi) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)  
                  
        return get_all_pool4xi() 
        
    #</methodize4xi>
    
    #One
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "get-one-of-ConstantPool4Xi" usage = "gets one pool constant">
    #<state4xi status = "<NACK4review; NACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------   
    def get_one(self, get_one_param=5):
        '''
        get_one method gets one pool constant
        '''       

                    
        class2print = "ConstantPool4Xi"
        method2print = 'get_one'
            
        message2print = "{started" + "; get-one-of-ConstantPool4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)        
    
        message2print = "{passed" + "; get-one-param-passed-to-get-one-of-ConstantPool4Xi: " + str(get_one_param) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)                    
        
        message2print = "{returning" + "; get-one-pool4xi-function-returning-by-get-one-of-ConstantPool4Xi: " + str(get_one_pool4xi) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)  
      
        return get_one_pool4xi(get_one_param)      
    #</methodize4xi>
                
    #1#
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "init-run-of-ConstantPool4Xi" usage = "initializes RUN_POOL4XI">
    #<state4xi status = "<NACK4review; NACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------    
    def init_run(self, init_run_param=0):          
        '''
        init_run initializes RUN_POOL4XI
        '''

                    
        class2print = "ConstantPool4Xi"
        method2print = 'init_run'
            
        message2print = "{started" + "; init-run-of-ConstantPool4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)        
    
    
        message2print = "{passed" + "; init-run-param-passed-to-init-run-of-ConstantPool4Xi: " + str(init_run_param) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)                    
      
        init_run_pool4xi(init_run_param)
    
        message2print = "{returning" + "; init-run-of-ConstantPool4Xi-returning: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)     
    #</methodize4xi>
         
    
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "set-run-of-ConstantPool4Xi" usage = "sets RUN_POOL4XI">
    #<state4xi status = "<NACK4review; NACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------    
    def set_run(self, set_run_param=0):          
        '''
        set_run sets RUN_POOL4XI
        '''

                    
        class2print = "ConstantPool4Xi"
        method2print = 'set_run'
            
        message2print = "{started" + "; set-run-of-ConstantPool4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)        
    
    
        message2print = "{passed" + "; set-run-param-passed-to-set-run-of-ConstantPool4Xi: " + str(set_run_param) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)                    
     
        set_run_pool4xi(set_run_param)
        
    
        message2print = "{returning" + "; set-run-of-ConstantPool4Xi-returning: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)      
    #</methodize4xi>
             
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "get-run-of-ConstantPool4Xi" usage = "gets RUN_POOL4XI">
    #<state4xi status = "<NACK4review; NACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------    
    def get_run(self):          
        '''
        get_run gets RUN_POOL4XI
        '''

                    
        class2print = "ConstantPool4Xi"
        method2print = 'get_run'
            
        message2print = "{started" + "; get-run-of-ConstantPool4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)        
    
                     
        message2print = "{returning" + "; get-run-pool4xi-function-returning-by-get-run-of-ConstantPool4Xi: " + str(get_run_pool4xi) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)  
    
        return get_run_pool4xi()      
    #</methodize4xi>
        
    #2#
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "init-close-of-ConstantPool4Xi" usage = "initializes CLOSE_POOL4XI">
    #<state4xi status = "<NACK4review; NACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------    
    def init_close(self, init_close_param=2):          
        '''
        init_close initializes CLOSE_POOL4XI
        '''

                    
        class2print = "ConstantPool4Xi"
        method2print = 'init_close'
            
        message2print = "{started" + "; init-close-of-ConstantPool4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)        
    
    
        message2print = "{passed" + "; init-close-param-passed-to-init-close-of-ConstantPool4Xi: " + str(init_close_param) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)                    
     
        init_close_pool4xi(init_close_param)
        
    
        message2print = "{returning" + "; init-close-of-ConstantPool4Xi-returning: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)    
     
    #</methodize4xi>
        
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "set-close-of-ConstantPool4Xi" usage = "sets CLOSE_POOL4XI">
    #<state4xi status = "<NACK4review; NACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------    
    def set_close(self, set_close_param=2):          
        '''
        set_close sets CLOSE_POOL4XI
        '''

                    
        class2print = "ConstantPool4Xi"
        method2print = 'set_close'
             
        message2print = "{started" + "; set-close-of-ConstantPool4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)        
    
    
        message2print = "{passed" + "; set-close-param-passed-to-set-close-of-ConstantPool4Xi: " + str(set_close_param) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)                    
      
        set_close_pool4xi(set_close_param)
    
        message2print = "{returning" + "; set-close-of-ConstantPool4Xi-returning: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)    
         
    #</methodize4xi>
            
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "get-close-of-ConstantPool4Xi" usage = "gets CLOSE_POOL4XI">
    #<state4xi status = "<NACK4review; NACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------    
    def get_close(self):          
        '''
        get_close gets CLOSE_POOL4XI
        '''
                

                    
        class2print = "ConstantPool4Xi"
        method2print = 'get_close'
            
        message2print = "{started" + "; get-close-of-ConstantPool4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)        
    
                     
        message2print = "{returning" + "; get-close-pool4xi-function-returning-by-get-close-of-ConstantPool4Xi: " + str(get_close_pool4xi) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)  
    
        return get_close_pool4xi()           
    #</methodize4xi>
        
    #3#
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "init-terminate-of-ConstantPool4Xi" usage = "initializes TERMINATE_POOL4XI">
    #<state4xi status = "<NACK4review; NACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------    
    def init_terminate(self, init_terminate_param=3):          
        '''
        init_terminate initializes TERMINATE_POOL4XI
        '''

                    
        class2print = "ConstantPool4Xi"
        method2print = 'init_terminate'
            
        message2print = "{started" + "; init-terminate-of-ConstantPool4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)        
    
    
        message2print = "{passed" + "; init-terminate-param-passed-to-init-terminate-of-ConstantPool4Xi: " + str(init_terminate_param) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)                    
      
        init_terminate_pool4xi(init_terminate_param)
    
        message2print = "{returning" + "; init-terminate-of-ConstantPool4Xi-returning: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)     
    #</methodize4xi>
         
    
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "set-terminate-of-ConstantPool4Xi" usage = "sets TERMINATE_POOL4XI">
    #<state4xi status = "<NACK4review; NACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------    
    def set_terminate(self, set_terminate_param=3):          
        '''
        set_terminate sets TERMINATE_POOL4XI
        '''

        class2print = "ConstantPool4Xi"
        method2print = 'set_terminate'
            
        message2print = "{started" + "; set-terminate-of-ConstantPool4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)        
    
    
        message2print = "{passed" + "; set-terminate-param-passed-to-set-terminate-of-ConstantPool4Xi: " + str(set_terminate_param) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)                    
       
        set_terminate_pool4xi(set_terminate_param)
    
        message2print = "{returning" + "; set-terminate-of-ConstantPool4Xi-returning: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)     
    #</methodize4xi>
             
        
        
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "get-terminate-of-ConstantPool4Xi" usage = "gets TERMINATE_POOL4XI">
    #<state4xi status = "<NACK4review; NACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------    
    def get_terminate(self):          
        '''
        get_terminate gets TERMINATE_POOL4XI
        '''
        

        class2print = "ConstantPool4Xi"
        method2print = 'get_terminate'
            
        message2print = "{started" + "; get-terminate-of-ConstantPool4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)        
  
                     
        message2print = "{returning" + "; get-terminate-pool4xi-function-returning-by-get-terminate-of-ConstantPool4Xi: " + str(get_terminate_pool4xi) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)  
         
        return get_terminate_pool4xi()        
    #</methodize4xi>
        
        
    #4#
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "init-exitpriority-of-ConstantPool4Xi" usage = "initializes EXITPRIORITY_POOL4XI">
    #<state4xi status = "<NACK4review; NACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------    
    def init_exitpriority(self, init_exitpriority_param=4):          
        '''
        init_exitpriority initializes EXITPRIORITY_POOL4XI
        '''

        class2print = "ConstantPool4Xi"
        method2print = 'init_exitpriority'
            
        message2print = "{started" + "; init-exitpriority-of-ConstantPool4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)        
    
    
        message2print = "{passed" + "; init-exitpriority-param-passed-to-init-exitpriority-of-ConstantPool4Xi: " + str(init_exitpriority_param) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)                    
      
        init_exitpriority_pool4xi(init_exitpriority_param)
    
        message2print = "{returning" + "; init-exitpriority-of-ConstantPool4Xi-returning: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)   
     
    #</methodize4xi>
        
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "set-exitpriority-of-ConstantPool4Xi" usage = "sets EXITPRIORITY_POOL4XI">
    #<state4xi status = "<NACK4review; NACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------    
    def set_exitpriority(self, set_exitpriority_param=4):          
        '''
        set_exitpriority sets EXITPRIORITY_POOL4XI
        '''

        class2print = "ConstantPool4Xi"
        method2print = 'set_exitpriority'
            
        message2print = "{started" + "; set-exitpriority-of-ConstantPool4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)        
    
    
        message2print = "{passed" + "; set-exitpriority-param-passed-to-set-exitpriority-of-ConstantPool4Xi: " + str(set_exitpriority_param) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)                    
      
        set_exitpriority_pool4xi(set_exitpriority_param)
    
        message2print = "{returning" + "; set-exitpriority-of-ConstantPool4Xi-returning: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)      
    #</methodize4xi>
             
        
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "get-exitpriority-of-ConstantPool4Xi" usage = "gets EXITPRIORITY_POOL4XI">
    #<state4xi status = "<NACK4review; NACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------    
    def get_exitpriority(self):          
        '''
        get_exitpriority gets EXITPRIORITY_POOL4XI
        '''

        class2print = "ConstantPool4Xi"
        method2print = 'get_exitpriority'
            
        message2print = "{started" + "; get-exitpriority-of-ConstantPool4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)        
    
                     
        message2print = "{returning" + "; get-exitpriority-pool4xi-function-returning-by-get-exitpriority-of-ConstantPool4Xi: " + str(get_exitpriority_pool4xi) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)  
     
        return get_exitpriority_pool4xi()  
    #</methodize4xi>
    
    #5#
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "init-job-counter-of-ConstantPool4Xi" usage = "initializes job_counter4xi">
    #<state4xi status = "<NACK4review; NACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------    
    def init_job_counter(self, init_job_counter_param=itertools.count()):          
        '''
        init_job_counter initializes job_counter4xi
        '''

        class2print = "ConstantPool4Xi"
        method2print = 'init_job_counter'
            
        message2print = "{started" + "; init-job-counter-of-ConstantPool4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)        
    
    
        message2print = "{passed" + "; init-job-counter-param-passed-to-init-job-counter-of-ConstantPool4Xi: " + str(init_job_counter_param) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)                    
       
        init_job_counter_pool4xi(init_job_counter_param)
    
        message2print = "{returning" + "; init-job-counter-of-ConstantPool4Xi-returning: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)      
    #</methodize4xi>
         
    
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "set-job-counter-of-ConstantPool4Xi" usage = "sets job_counter4xi">
    #<state4xi status = "<NACK4review; NACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------    
    def set_job_counter(self, set_job_counter_param=itertools.count()):          
        '''
        set_job_counter sets job_counter4xi
        '''

        class2print = "ConstantPool4Xi"
        method2print = 'set_job_counter'
            
        message2print = "{started" + "; set-job-counter-of-ConstantPool4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)        
    
    
        message2print = "{passed" + "; set-job-counter-param-passed-to-set-job-counter-of-ConstantPool4Xi: " + str(set_job_counter_param) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)                    
      
        set_job_counter_pool4xi(set_job_counter_param)
    
        message2print = "{returning" + "; set-job-counter-of-ConstantPool4Xi-returning: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)    
    #</methodize4xi>
             
        
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "get-job-counter-of-ConstantPool4Xi" usage = "gets job_counter4xi">
    #<state4xi status = "<NACK4review; NACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------    
    def get_job_counter(self):          
        '''
        get_job_counter gets job_counter4xi
        '''

        class2print = "ConstantPool4Xi"
        method2print = 'get_job_counter'
            
        message2print = "{started" + "; get-job-counter-of-ConstantPool4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)        
    
                     
        message2print = "{returning" + "; get-job-counter-pool4xi-function-returning-by-get-job-counter-of-ConstantPool4Xi: " + str(get_job_counter_pool4xi) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)  
    
        return get_job_counter_pool4xi()  
    #</methodize4xi>
    
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "next-job-counter-of-ConstantPool4Xi" usage = "returns next job_counter4xi">
    #<state4xi status = "<NACK4review; NACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
    # -------------------------------------------------------------------------------------------------    
    def next_job_counter(self):          
        '''
        next_job_counter returns next job_counter4xi
        '''

        class2print = "ConstantPool4Xi"
        method2print = 'next_job_counter'
            
        message2print = "{started" + "; next-job-counter-of-ConstantPool4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)        
    
                     
        message2print = "{returning" + "; next-job-counter-pool4xi-function-returning-by-next-job-counter-of-ConstantPool4Xi: " + str(next_job_counter_pool4xi) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)  
     
        return next_job_counter_pool4xi()               
    #</methodize4xi>
                                           
    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "sense-of-ConstantPool4Xi" usage = "senses class objects">
    #<state4xi status = "<NACK4review; NACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
    # ---------------------------------------------------------------------------------------------
    def sense(self):
        '''
        senses ConstantPool4Xi class objects
        '''
          
        
        class2print = 'ConstantPool4Xi'
        method2print = 'sense'
        
        message2print = "{started" + "; sense-of-ConstantPool4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)          
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------  
        message2print = "{sensing" + "; constantpool4xi-sensing-by-sense-of-ConstantPool4Xi: " + str(ConstantPool4Xi)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)         
                        
        
        # -----------------------------------------------------------------------------------------
        # get sensed knowledge for this object
        # -----------------------------------------------------------------------------------------        
        kb2xi = sense_object4xi(self)
        
        message2print = "{got" + "; kb2xi-got-by-sense-of-ConstantPool4Xi: " + str(kb2xi)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
                
        
        # -----------------------------------------------------------------------------------------
        # add knowledge specific to this object
        # -----------------------------------------------------------------------------------------         
        try:
            kb2xi['inheritance-of-constantpool2xi'] = object
        
        except:
            message2print = "{yielded" + "; kb2xi-yielded-by-sense-of-ConstantPool4Xi: " + str(kb2xi)  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print) 
            
      
        message2print = "{sensed" + "; constantpool4xi-sensed-by-sense-of-ConstantPool4Xi: " + str(ConstantPool4Xi)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)       
        
        # -----------------------------------------------------------------------------------------
        # 
        # -----------------------------------------------------------------------------------------         
        message2print = "{returning" + "; kb2xi-returning-by-sense-of-ConstantPool4Xi: " + str(kb2xi) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)    
                                 
          
        return kb2xi
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------        
    #</methodize4xi>
    
        
    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "reason-of-ConstantPool4Xi" usage = "reasons class objects">
    #<state4xi status = "<NACK4review; NACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
    # ---------------------------------------------------------------------------------------------
    def reason(self):
        '''
        reasons ConstantPool4Xi class objects
        '''
                 
        
        class2print = 'ConstantPool4Xi'
        method2print = 'reason'

        message2print = "{started" + "; reason-of-ConstantPool4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)                  
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------
        message2print = "{reasoning" + "; constantpool4xi-reasoning-by-reason-of-ConstantPool4Xi: " + str(ConstantPool4Xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print) 
                
        
        # -----------------------------------------------------------------------------------------
        # get reasoned knowledge for this object
        # -----------------------------------------------------------------------------------------         
        kb4xi = reason_object4xi(self)
        
        
        message2print = "{got" + "; kb4xi-got-by-reason-of-ConstantPool4Xi: " + str(kb4xi)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
                
        
        # -----------------------------------------------------------------------------------------
        # add knowledge specific to this object
        # format example: kb4xi['time2xi'] = time4xi() #adding time 
        # -----------------------------------------------------------------------------------------          
        
        
          
        
        message2print = "{reasoned" + "; constantpool4xi-reasoned-by-reason-of-ConstantPool4Xi: " + str(ConstantPool4Xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)        
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------        
        message2print = "{returning" + "; kb4xi-returning-by-reason-of-ConstantPool4Xi: " + str(kb4xi) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)    
                                 
          
        return kb4xi
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------            
    #</methodize4xi>
    
    
    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "ace-of-ConstantPool4Xi" usage = "aces class objects">
    #<state4xi status = "<NACK4review; NACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
    # ---------------------------------------------------------------------------------------------
    def ace(self):
        '''
        aces ConstantPool4Xi class objects 
        '''
               
        
        
        class2print = 'ConstantPool4Xi'
        method2print = 'ace'
        
        message2print = "{started" + "; ace-of-ConstantPool4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)                       
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------
        message2print = "{acing" + "; constantpool4xi-acing-by-ace-of-ConstantPool4Xi: " + str(ConstantPool4Xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)         
                      
        
        # -----------------------------------------------------------------------------------------
        # get aced knowledge for this object
        # -----------------------------------------------------------------------------------------        
        kb8xi = ace_object4xi(self)  
        
        message2print = "{got" + "; kb8xi-got-by-ace-of-ConstantPool4Xi: " + str(kb8xi)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
                


        # -----------------------------------------------------------------------------------------
        # add knowledge specific to this object
        # format example: kb8xi['time2xi'] = time4xi() #adding time 
        # -----------------------------------------------------------------------------------------              
        
          
        message2print = "{aced" + "; constantpool4xi-aced-by-ace-of-ConstantPool4Xi: " + str(ConstantPool4Xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)          
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------        
        message2print = "{returning" + "; kb8xi-returning-by-ace-of-ConstantPool4Xi: " + str(kb8xi) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)    
                                 
        
        return kb8xi
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------
        #</methodize4xi>
#</class4xi>
#</program4xi>
 

# -------------------------------------------------------------------------------------------------
# Recorded History                             
# ------------------------------------------------------------------------------------------------- 
#<record4xi record = "
#   test_constant_pool4xi.txt
#   sense-test-constant-pool4xi.xml
#   reason-test-constant-pool4xi.xml
#   ace-test-constant-pool4xi.xml

#   test_proxy_mp_xi4.txt
#   sense-proxy-mp-test4xi.xml
#   reason-proxy-mp-test4xi.xml
#   ace-proxy-mp-test4xi.xml


#"
#>


# -------------------------------------------------------------------------------------------------
# Legal Notice                             
# ------------------------------------------------------------------------------------------------- 
#<protect4xi protection = "copyright"
#   owner = "Small & Smart"
#   rights = "All rights reserved"
#   state = "California"
#   country = "United States of America"
#   references = "Legal notice at www.dragonxi.com; www.yourdragonxi.com; www.yourdragonxi.org; www.dragon2xi.com/; www.dragon4xi.com/; www.dragon8xi.com/ " 
#   codes = "Codes established in California and applicable to corporations in California"
#   compliance = "The California Law"
#   court = "Supreme Court of California, 350 McAllister Street, San Francisco, CA 94102-4783"
#/>

    
    


#<end4xi end = "
# -------------------------------------------------------------------------------------------------
# end of constant_pool4xi.py                             
# ------------------------------------------------------------------------------------------------- 
#"
#/>
                      